@@ -1,3 +1,20 @@
+# This file is part of CycloneDX Python
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# SPDX-License-Identifier: Apache-2.0
+# Copyright (c) OWASP Foundation. All Rights Reserved.
+
 """
 initialize this testbed.
 """
@@ -5,7 +22,7 @@ initialize this testbed.
 from os import name as os_name
 from os.path import dirname, join
 from subprocess import PIPE, CompletedProcess, run  # nosec:B404
-from sys import argv, executable
+from sys import argv, executable, stderr
 from typing import Any
 from venv import EnvBuilder
 
@@ -18,12 +35,10 @@ constraint_file = join(this_dir, 'pinning.txt')
 
 def pip_run(*args: str, **kwargs: Any) -> CompletedProcess:
     # pip is not API, but a CLI -- call it like that!
-    call = (
-        executable, '-m', 'pip',
-        '--python', env_dir,
-        *args
-    )
-    print('+ ', *call)
+    call = (executable, '-m', 'pip',
+            '--python', env_dir,
+            *args)
+    print('+ ', *call, file=stderr)
     res = run(call, **kwargs, cwd=this_dir, shell=False)  # nosec:B603
     if res.returncode != 0:
         raise RuntimeError('process failed')
@@ -46,8 +61,10 @@ def main() -> None:
     ).create(env_dir)
 
     pip_install(
+        '--no-deps',  # the clib dep cannot be installed consistently...
         # https://packaging.python.org/en/latest/specifications/name-normalization/#name-normalization
         'ruamel-YAML[jinja2]',  # actually "ruamel.yaml", normalizes to "ruamel-yaml"
+        'ruamel-Yaml.Jinja2',  # actually "ruamel.yaml.jinja2", normalizes to "ruamel-yaml-jinja2"
     )
 
 
