@@ -22,24 +22,21 @@ initialize this testbed.
 from os import environ
 from os.path import dirname
 from subprocess import CompletedProcess, run  # nosec:B404
-from sys import executable
+from sys import executable, stderr
 
 __all__ = ['main']
 
 this_dir = dirname(__file__)
 
-
 poetry_env = environ.copy()
 poetry_env['VIRTUAL_ENV'] = ''
 
 
 def poetry_run(*args: str) -> CompletedProcess:
     # Poetry is not API, but a CLI -- call it like that!
-    call = (
-        executable, '-m', 'poetry',
-        *args
-    )
-    print('+ ', *call)
+    call = (executable, '-m', 'poetry',
+            *args)
+    print('+ ', *call, file=stderr)
     res = run(call, cwd=this_dir, env=poetry_env, shell=False)  # nosec:B603
     if res.returncode != 0:
         raise RuntimeError('process failed')
