@@ -22,7 +22,7 @@ initialize this testbed.
 from os import name as os_name
 from os.path import dirname, join
 from subprocess import PIPE, CompletedProcess, run  # nosec:B404
-from sys import argv, executable
+from sys import argv, executable, stderr
 from typing import Any
 from venv import EnvBuilder
 
@@ -35,12 +35,10 @@ constraint_file = join(this_dir, 'pinning.txt')
 
 def pip_run(*args: str, **kwargs: Any) -> CompletedProcess:
     # pip is not API, but a CLI -- call it like that!
-    call = (
-        executable, '-m', 'pip',
-        '--python', env_dir,
-        *args
-    )
-    print('+ ', *call)
+    call = (executable, '-m', 'pip',
+            '--python', env_dir,
+            *args)
+    print('+ ', *call, file=stderr)
     res = run(call, **kwargs, cwd=this_dir, shell=False)  # nosec:B603
     if res.returncode != 0:
         raise RuntimeError('process failed')
@@ -65,14 +63,17 @@ def main() -> None:
     pip_install(
         '--no-dependencies',
         # with License-Expression
-        'attrs',
+        'attrs==23.2.0',
         # with License-File
-        'boolean.py',
-        'jsonpointer',
-        'license_expression',
-        'lxml',
+        'boolean.py==4.0',
+        'jsonpointer==2.4',
+        'license_expression==30.3.0',
+        'chardet==5.2.0',  # https://github.com/CycloneDX/cyclonedx-python/issues/931
         # with expression-like License AND License-File
         'cryptography==43.0.1',  # https://github.com/CycloneDX/cyclonedx-python/issues/826
+        # with possibly unexpected license files
+        # https://github.com/CycloneDX/cyclonedx-python/issues/868
+        '../../_helpers/local_pckages/with-license-pep639_regression-issue868',
     )
 
 
