@@ -1,4 +1,4 @@
-# This file is part of CycloneDX Python Lib
+# This file is part of CycloneDX Python
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,12 +21,12 @@ from unittest import TestCase
 from cyclonedx.spdx import is_supported_id
 from ddt import ddt, named_data
 
-from cyclonedx_py._internal.utils.license_trove_classifier import __TO_SPDX_MAP as TO_SPDX_MAP
+from cyclonedx_py._internal.utils.license_trove_classifier import _MAP_TO_SPDX
 
 
 @ddt
 class TestLicenseTroveClassifier(TestCase):
 
-    @named_data(*TO_SPDX_MAP.items())
+    @named_data(*_MAP_TO_SPDX.items())
     def test_map_is_known_id(self, mapped: str) -> None:
         self.assertTrue(is_supported_id(mapped))
