@@ -16,12 +16,13 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 import random
+from collections.abc import Generator
 from glob import glob
 from os import name as os_name
 from os.path import basename, dirname, join
 from subprocess import run  # nosec:B404
 from sys import executable, stderr
-from typing import Any, Generator
+from typing import Any
 from unittest import TestCase, skipIf
 
 from cyclonedx.schema import OutputFormat, SchemaVersion
@@ -79,7 +80,7 @@ class TestCliEnvironment(TestCase, SnapshotMixin):
             '-vvv',
             f'--sv={sv.to_version()}',
             f'--of={of.name}',
-            '--outfile=-',
+            '-o=-',
             wrong_python)
         self.assertNotEqual(0, res, err)
         self.assertIn(expected_error, err)
@@ -96,7 +97,7 @@ class TestCliEnvironment(TestCase, SnapshotMixin):
             '-vvv',
             f'--sv={sv.to_version()}',
             f'--of={of.name}',
-            '--outfile=-',
+            '-o=-',
             wrong_python)
         self.assertNotEqual(0, res, err)
         self.assertIn(expected_error, err)
@@ -108,7 +109,7 @@ class TestCliEnvironment(TestCase, SnapshotMixin):
             '-vvv',
             '--sv', sv.to_version(),
             '--of', of.name,
-            '--outfile=-',
+            '-o=-',
             '--pyproject=something-that-must-not-exist.testing',
             projectdir
         )
@@ -124,7 +125,7 @@ class TestCliEnvironment(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             # no project dir -> search in current python
         )
         self.assertEqual(0, res, err)
@@ -134,7 +135,7 @@ class TestCliEnvironment(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             executable  # explicitly current python
         )
         self.assertEqual(0, res, err)
@@ -151,44 +152,13 @@ class TestCliEnvironment(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             '--pyproject', join(projectdir, 'pyproject.toml'),
             join(projectdir, '.venv'))
         self.assertEqual(0, res, err)
         self.assertEqualSnapshot(out, 'plain', projectdir, sv, of)
 
-    @named_data(*test_data_file_filter('pep639'))
-    def test_pep639_as_expected(self, projectdir: str, sv: SchemaVersion, of: OutputFormat) -> None:
-        res, out, err = run_cli(
-            'environment',
-            '-vvv',
-            '--sv', sv.to_version(),
-            '--of', of.name,
-            '--output-reproducible',
-            '--outfile=-',
-            '--pyproject', join(projectdir, 'pyproject.toml'),
-            '--PEP-639',
-            join(projectdir, '.venv'))
-        self.assertEqual(0, res, err)
-        self.assertEqualSnapshot(out, 'pep639', projectdir, sv, of)
-
-    @named_data(*test_data_file_filter('pep639'))
-    def test_pep639_texts_as_expected(self, projectdir: str, sv: SchemaVersion, of: OutputFormat) -> None:
-        res, out, err = run_cli(
-            'environment',
-            '-vvv',
-            '--sv', sv.to_version(),
-            '--of', of.name,
-            '--output-reproducible',
-            '--outfile=-',
-            '--pyproject', join(projectdir, 'pyproject.toml'),
-            '--PEP-639',
-            '--gather-license-texts',
-            join(projectdir, '.venv'))
-        self.assertEqual(0, res, err)
-        self.assertEqualSnapshot(out, 'pep639-texts', projectdir, sv, of)
-
-    @named_data(*test_data_file_filter('pep639'))
+    @named_data(*test_data_file_filter('with-license-'))
     def test_texts_as_expected(self, projectdir: str, sv: SchemaVersion, of: OutputFormat) -> None:
         res, out, err = run_cli(
             'environment',
@@ -196,7 +166,7 @@ class TestCliEnvironment(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             '--pyproject', join(projectdir, 'pyproject.toml'),
             '--gather-license-texts',
             join(projectdir, '.venv'))
