@@ -17,9 +17,10 @@
 
 
 import random
+from collections.abc import Generator
 from glob import glob
 from os.path import basename, dirname, join
-from typing import Any, Generator
+from typing import Any
 from unittest import TestCase
 
 from cyclonedx.schema import OutputFormat, SchemaVersion
@@ -56,7 +57,7 @@ class TestCliPoetry(TestCase, SnapshotMixin):
             '-vvv',
             '--sv', sv.to_version(),
             '--of', of.name,
-            '--outfile=-',
+            '-o=-',
             'something-that-must-not-exist.testing')
         self.assertNotEqual(0, res, err)
         self.assertIn('Could not open pyproject file: something-that-must-not-exist.testing', err)
@@ -109,7 +110,7 @@ class TestCliPoetry(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             projectdir)
         self.assertEqual(0, res, err)
         self.assertEqualSnapshot(out, 'plain', projectdir, sv, of)
@@ -124,7 +125,7 @@ class TestCliPoetry(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             projectdir)
         self.assertEqual(0, res, err)
         self.assertEqualSnapshot(out, 'some-groups', projectdir, sv, of)
@@ -138,7 +139,7 @@ class TestCliPoetry(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             projectdir)
         self.assertEqual(0, res, err)
         self.assertEqualSnapshot(out, 'only-groups', projectdir, sv, of)
@@ -153,7 +154,7 @@ class TestCliPoetry(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             projectdir)
         self.assertEqual(0, res, err)
         self.assertEqualSnapshot(out, 'no-dev', projectdir, sv, of)
@@ -167,7 +168,7 @@ class TestCliPoetry(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             projectdir)
         self.assertEqual(0, res, err)
         self.assertEqualSnapshot(out, 'some-extras', projectdir, sv, of)
@@ -181,7 +182,7 @@ class TestCliPoetry(TestCase, SnapshotMixin):
             '--sv', sv.to_version(),
             '--of', of.name,
             '--output-reproducible',
-            '--outfile=-',
+            '-o=-',
             projectdir)
         self.assertEqual(0, res, err)
         self.assertEqualSnapshot(out, 'all-extras', projectdir, sv, of)
